@@ -1,6 +1,6 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
-    Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
+    2012, 2013 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include <cctype>
 #include <cstdio>
 #include <vector>
+#include <stdint.h>
 
 #include "common.h"
 #include "rectangle.h"
@@ -27,7 +28,7 @@
 
 
     // Creates a blank Bitmap
-Bitmap::Bitmap( const int l, const int t, const int r, const int b ) throw()
+Bitmap::Bitmap( const int l, const int t, const int r, const int b )
   : Rectangle( l, t, r, b ), data( height() )
   {
   for( int row = 0; row < height(); ++row )
@@ -36,7 +37,7 @@ Bitmap::Bitmap( const int l, const int t, const int r, const int b ) throw()
 
 
     // Creates a Bitmap from part of another Bitmap
-Bitmap::Bitmap( const Bitmap & source, const Rectangle & re ) throw()
+Bitmap::Bitmap( const Bitmap & source, const Rectangle & re )
   : Rectangle( re ), data( re.height() )
   {
   if( !source.includes( re ) )
@@ -48,15 +49,15 @@ Bitmap::Bitmap( const Bitmap & source, const Rectangle & re ) throw()
   for( int row = 0; row < height(); ++row )
     {
     data[row].resize( width() );
-    std::vector< unsigned char > & datarow = data[row];
-    const std::vector< unsigned char > & datarow2 = source.data[row+tdiff];
+    std::vector< uint8_t > & datarow = data[row];
+    const std::vector< uint8_t > & datarow2 = source.data[row+tdiff];
     for( int col = 0; col < width(); ++col )
       datarow[col] = datarow2[col+ldiff];
     }
   }
 
 
-void Bitmap::left( const int l ) throw()
+void Bitmap::left( const int l )
   {
   if( l == left() ) return;
   if( l < left() )
@@ -64,24 +65,24 @@ void Bitmap::left( const int l ) throw()
       data[row].insert( data[row].begin(), left() - l, false );
   else
     for( int row = height() - 1; row >= 0 ; --row )
-      data[row].erase( data[row].begin(), data[row].begin() + l - left() );
+      data[row].erase( data[row].begin(), data[row].begin() + ( l - left() ) );
   Rectangle::left( l );
   }
 
 
-void Bitmap::top( const int t ) throw()
+void Bitmap::top( const int t )
   {
   if( t == top() ) return;
   if( t < top() )
     data.insert( data.begin(), top() - t,
-                 std::vector< unsigned char >( width(), false ) );
+                 std::vector< uint8_t >( width(), false ) );
   else
-    data.erase( data.begin(), data.begin() + t - top() );
+    data.erase( data.begin(), data.begin() + ( t - top() ) );
   Rectangle::top( t );
   }
 
 
-void Bitmap::right( const int r ) throw()
+void Bitmap::right( const int r )
   {
   if( r == right() ) return;
   Rectangle::right( r );
@@ -90,7 +91,7 @@ void Bitmap::right( const int r ) throw()
   }
 
 
-void Bitmap::bottom( const int b ) throw()
+void Bitmap::bottom( const int b )
   {
   if( b == bottom() ) return;
   int old_height = height();
@@ -101,7 +102,7 @@ void Bitmap::bottom( const int b ) throw()
   }
 
 
-void Bitmap::add_bitmap( const Bitmap & bm ) throw()
+void Bitmap::add_bitmap( const Bitmap & bm )
   {
   add_rectangle( bm );
   for( int row = bm.top(); row <= bm.bottom(); ++row )
@@ -110,7 +111,7 @@ void Bitmap::add_bitmap( const Bitmap & bm ) throw()
   }
 
 
-void Bitmap::add_point( const int row, const int col ) throw()
+void Bitmap::add_point( const int row, const int col )
   {
   if( col > right() ) right( col ); else if( col < left() ) left( col );
   if( row > bottom() ) bottom( row ); else if( row < top() ) top( row );
@@ -118,7 +119,7 @@ void Bitmap::add_point( const int row, const int col ) throw()
   }
 
 
-void Bitmap::add_rectangle( const Rectangle & re ) throw()
+void Bitmap::add_rectangle( const Rectangle & re )
   {
   if( re.left() < left() )     left( re.left() );
   if( re.top() < top() )       top( re.top() );
@@ -127,9 +128,9 @@ void Bitmap::add_rectangle( const Rectangle & re ) throw()
   }
 
 
-// Returns true if height is or can be adjusted
+// Returns false if bitmap is empty
 //
-bool Bitmap::adjust_height() throw()
+bool Bitmap::adjust_height()
   {
   int row1, row2;
 
@@ -141,18 +142,37 @@ bool Bitmap::adjust_height() throw()
     for( int col = left(); col <= right(); ++col )
       if( get_bit( row2, col ) ) goto L2;
   L2:
-  if( row1 > top() || row2 < bottom() )
-    {
-    if( row1 <= row2 ) { top( row1 ); bottom( row2 ); }
-    else return false;
-    }
+  if( row1 > row2 ) return false;
+  if( row1 > top() ) top( row1 );
+  if( row2 < bottom() ) bottom( row2 );
+  return true;
+  }
+
+
+// Returns false if bitmap is empty
+//
+bool Bitmap::adjust_width()
+  {
+  int col1, col2;
+
+  for( col1 = left(); col1 <= right(); ++col1 )
+    for( int row = top(); row <= bottom(); ++row )
+      if( get_bit( row , col1 ) ) goto L1;
+  L1:
+  for( col2 = right(); col2 >= col1; --col2 )
+    for( int row = top(); row <= bottom(); ++row )
+      if( get_bit( row , col2) ) goto L2;
+  L2:
+  if( col1 >= col2 ) return false;
+  if( col1 > left() ) left( col1 );
+  if( col2 < right() ) right( col2 );
   return true;
   }
 
 
 // Return the total filled area of this Bitmap
 //
-int Bitmap::area() const throw()
+int Bitmap::area() const
   {
   int a = 0;
 
@@ -166,7 +186,7 @@ int Bitmap::area() const throw()
 
 // Return the central octagon filled area of this Bitmap
 //
-int Bitmap::area_octagon() const throw()
+int Bitmap::area_octagon() const
   {
   int a = 0;
   int bevel = ( 29 * std::min( height(), width() ) ) / 100;
@@ -191,14 +211,14 @@ int Bitmap::area_octagon() const throw()
 
 // Return the size of the central octagon of this blob
 //
-int Bitmap::size_octagon() const throw()
+int Bitmap::size_octagon() const
   {
   int bevel = ( 29 * std::min( height(), width() ) ) / 100;
   return size() - ( 2 * bevel * ( bevel + 1 ) );
   }
 
 
-int Bitmap::seek_left( const int row, const int col, const bool black ) const throw()
+int Bitmap::seek_left( const int row, const int col, const bool black ) const
   {
   int c = col;
   while( c > left() && get_bit( row, c - 1 ) != black ) --c;
@@ -206,7 +226,7 @@ int Bitmap::seek_left( const int row, const int col, const bool black ) const th
   }
 
 
-int Bitmap::seek_top( const int row, const int col, const bool black ) const throw()
+int Bitmap::seek_top( const int row, const int col, const bool black ) const
   {
   int r = row;
   while( r > top() && get_bit( r - 1, col ) != black ) --r;
@@ -214,7 +234,7 @@ int Bitmap::seek_top( const int row, const int col, const bool black ) const thr
   }
 
 
-int Bitmap::seek_right( const int row, const int col, const bool black ) const throw()
+int Bitmap::seek_right( const int row, const int col, const bool black ) const
   {
   int c = col;
   while( c < right() && get_bit( row, c + 1 ) != black ) ++c;
@@ -222,7 +242,7 @@ int Bitmap::seek_right( const int row, const int col, const bool black ) const t
   }
 
 
-int Bitmap::seek_bottom( const int row, const int col, const bool black ) const throw()
+int Bitmap::seek_bottom( const int row, const int col, const bool black ) const
   {
   int r = row;
   while( r < bottom() && get_bit( r + 1, col ) != black ) ++r;
@@ -230,7 +250,7 @@ int Bitmap::seek_bottom( const int row, const int col, const bool black ) const
   }
 
 
-bool Bitmap::escape_left( int row, int col ) const throw()
+bool Bitmap::escape_left( int row, int col ) const
   {
   if( get_bit( row, col ) ) return false;
   int u, d;
@@ -248,7 +268,7 @@ bool Bitmap::escape_left( int row, int col ) const throw()
   }
 
 
-bool Bitmap::escape_top( int row, int col ) const throw()
+bool Bitmap::escape_top( int row, int col ) const
   {
   if( get_bit( row, col ) ) return false;
   int l, r;
@@ -266,7 +286,7 @@ bool Bitmap::escape_top( int row, int col ) const throw()
   }
 
 
-bool Bitmap::escape_right( int row, int col ) const throw()
+bool Bitmap::escape_right( int row, int col ) const
   {
   if( get_bit( row, col ) ) return false;
   int u, d;
@@ -284,7 +304,7 @@ bool Bitmap::escape_right( int row, int col ) const throw()
   }
 
 
-bool Bitmap::escape_bottom( int row, int col ) const throw()
+bool Bitmap::escape_bottom( int row, int col ) const
   {
   if( get_bit( row, col ) ) return false;
   int l, r;
@@ -302,10 +322,10 @@ bool Bitmap::escape_bottom( int row, int col ) const throw()
   }
 
 
-int Bitmap::follow_top( int row, int col ) const throw()
+int Bitmap::follow_top( int row, int col ) const
   {
   if( !get_bit( row, col ) ) return row;
-  std::vector< unsigned char > array;
+  std::vector< uint8_t > array;
   array.reserve( width() );
   int c;
 
@@ -334,10 +354,10 @@ int Bitmap::follow_top( int row, int col ) const throw()
   }
 
 
-int Bitmap::follow_bottom( int row, int col ) const throw()
+int Bitmap::follow_bottom( int row, int col ) const
   {
   if( !get_bit( row, col ) ) return row;
-  std::vector< unsigned char > array;
+  std::vector< uint8_t > array;
   array.reserve( width() );
   int c;
 
@@ -369,7 +389,7 @@ int Bitmap::follow_bottom( int row, int col ) const throw()
 // Looks for an inverted-U-shaped curve near the top, then tests which of
 // the vertical bars goes deeper
 //
-bool Bitmap::top_hook( int *hdiff ) const throw()
+bool Bitmap::top_hook( int *hdiff ) const
   {
   int row, lcol = 0, rcol = 0, black_section = 0, wmax = 0;
 
@@ -407,7 +427,7 @@ bool Bitmap::top_hook( int *hdiff ) const throw()
 // Looks for an U-shaped curve near the bottom, then tests which of
 // the vertical bars is taller
 //
-bool Bitmap::bottom_hook( int *hdiff ) const throw()
+bool Bitmap::bottom_hook( int *hdiff ) const
   {
   int row, lcol = 0, rcol = 0, black_section = 0, wmax = 0;
 
