@@ -1,6 +1,6 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
-    Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
+    2012, 2013 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ public:
   Blob( const Blob & b );
   Blob & operator=( const Blob & b );
 
-  ~Blob() throw();
+  ~Blob();
 
   using Bitmap::left;
   using Bitmap::top;
@@ -45,12 +45,16 @@ public:
   void height( const int h ) { bottom( top() + h - 1 ); }
   void width ( const int w ) { right( left() + w - 1 ); }
 
-  const Bitmap & hole( const int i ) const throw();
-  int holes() const throw() { return holepv.size(); }
+  const Bitmap & hole( const int i ) const;
+  int holes() const { return holepv.size(); }
   //  id = 1 for blob dots, negative for hole dots, 0 otherwise
-  int id( const int row, const int col ) const throw();
+  int id( const int row, const int col ) const;
 
-  void print( FILE * const outfile ) const throw();
+  bool is_abnormal() const
+    { return height() < 10 || height() >= 5 * width() || width() >= 3 * height(); }
+  bool test_BD() const;
+  bool test_Q() const;
+  void print( FILE * const outfile ) const;
 
   void fill_hole( const int i );
   void find_holes();
