@@ -1,6 +1,6 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
-    Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
+    2012, 2013 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,9 +19,11 @@
 #include <cstdio>
 #include <cstdlib>
 #include <vector>
+#include <stdint.h>
 
 #include "common.h"
 #include "rectangle.h"
+#include "segment.h"
 #include "ucs.h"
 #include "bitmap.h"
 #include "blob.h"
@@ -102,7 +104,7 @@ void Character::recognize12( const Charset & charset, const Rectangle & charbox
       int code = f1.test_solid( charbox );		//FIXME all this
       if( code == '-' && 2 * b1.height() > b1.width() ) code = '.';
       else if( code == '\'' || code == '|' ) code = '.';
-      if( !code && !b1.holes() && 
+      if( !code && !b1.holes() &&
           2 * b1.height() < b2.height() && b1.width() <= b2.width() )
         {
         if( 10 * a1 >= 7 * b1.height() * b1.width() ) code = '.';
@@ -227,7 +229,7 @@ void Character::recognize12( const Charset & charset, const Rectangle & charbox
   if( b1.bottom() <= b2.top() )
     {
     const int code = f2.test_solid( charbox );
-    if( !b1.holes() && ( code == '.' || 
+    if( !b1.holes() && ( code == '.' ||
           ( code && Ocrad::similar( b2.height(), b2.width(), 50 ) ) ) )
       {
       if( Ocrad::similar( b1.width(), b2.width(), 50 ) && !f1.lp.isctip() )
