@@ -1,6 +1,6 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
-    Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
+    2012, 2013 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -74,7 +74,7 @@ const T_entry T_table[] =
 
 int verbosity = 0;
 
-void Ocrad::internal_error( const char * const msg ) throw()
+void Ocrad::internal_error( const char * const msg )
   {
   std::fprintf( stderr, "ocrad: internal error: %s.\n", msg );
   std::exit( 3 );
@@ -82,7 +82,7 @@ void Ocrad::internal_error( const char * const msg ) throw()
 
 
 bool Ocrad::similar( const int a, const int b,
-                     const int percent_dif, const int abs_dif ) throw()
+                     const int percent_dif, const int abs_dif )
   {
   int difference = std::abs( a - b );
   if( percent_dif > 0 && difference <= abs_dif ) return true;
@@ -91,7 +91,7 @@ bool Ocrad::similar( const int a, const int b,
   }
 
 
-bool Charset::enable( const char * const name ) throw()
+bool Charset::enable( const char * const name )
   {
   for( int i = 0; i < charsets; ++i )
     if( std::strcmp( name, charset_name[i] ) == 0 )
@@ -100,14 +100,14 @@ bool Charset::enable( const char * const name ) throw()
   }
 
 
-bool Charset::enabled( const Value cset ) const throw()
+bool Charset::enabled( const Value cset ) const
   {
   if( !charset_ ) return cset == iso_8859_15;		// default charset
   return charset_ & cset;
   }
 
 
-bool Charset::only( const Value cset ) const throw()
+bool Charset::only( const Value cset ) const
   {
   if( !charset_ ) return cset == iso_8859_15;		// default charset
   return charset_ == cset;
@@ -115,12 +115,12 @@ bool Charset::only( const Value cset ) const throw()
 
 
 void Charset::show_error( const char * const program_name,
-                          const char * const arg ) const throw()
+                          const char * const arg ) const
   {
   if( verbosity >= 0 )
     {
     if( arg && std::strcmp( arg, "help" ) )
-      std::fprintf( stderr,"%s: bad charset `%s'\n", program_name, arg );
+      std::fprintf( stderr,"%s: bad charset '%s'\n", program_name, arg );
     std::fputs( "Valid charset names are:", stderr );
     for( int i = 0; i < charsets; ++i )
       std::fprintf( stderr, "  %s", charset_name[i] );
@@ -129,7 +129,7 @@ void Charset::show_error( const char * const program_name,
   }
 
 
-bool Filter::set( const char * const name ) throw()
+bool Filter::set( const char * const name )
   {
   for( int i = 0; F_table[i].name != 0; ++i )
     if( std::strcmp( name, F_table[i].name ) == 0 )
@@ -139,12 +139,12 @@ bool Filter::set( const char * const name ) throw()
 
 
 void Filter::show_error( const char * const program_name,
-                         const char * const arg ) const throw()
+                         const char * const arg ) const
   {
   if( verbosity >= 0 )
     {
     if( arg && std::strcmp( arg, "help" ) )
-      std::fprintf( stderr,"%s: bad filter `%s'\n", program_name, arg );
+      std::fprintf( stderr,"%s: bad filter '%s'\n", program_name, arg );
     std::fputs( "Valid filter names are:", stderr );
     for( int i = 0; F_table[i].name != 0; ++i )
       std::fprintf( stderr, "  %s", F_table[i].name );
@@ -153,7 +153,7 @@ void Filter::show_error( const char * const program_name,
   }
 
 
-bool Transformation::set( const char * const name ) throw()
+bool Transformation::set( const char * const name )
   {
   for( int i = 0; T_table[i].name != 0; ++i )
     if( std::strcmp( name, T_table[i].name ) == 0 )
@@ -163,12 +163,12 @@ bool Transformation::set( const char * const name ) throw()
 
 
 void Transformation::show_error( const char * const program_name,
-                                 const char * const arg ) const throw()
+                                 const char * const arg ) const
   {
   if( verbosity >= 0 )
     {
     if( arg && std::strcmp( arg, "help" ) )
-      std::fprintf( stderr,"%s: bad bitmap trasformation `%s'\n", program_name, arg );
+      std::fprintf( stderr,"%s: bad bitmap trasformation '%s'\n", program_name, arg );
     std::fputs( "Valid transformation names are:", stderr );
     for( int i = 0; T_table[i].name != 0; ++i )
       std::fprintf( stderr, "  %s", T_table[i].name );
@@ -177,9 +177,9 @@ void Transformation::show_error( const char * const program_name,
   }
 
 
-bool Control::set_format( const char * const name ) throw()
+bool Control::set_format( const char * const name )
   {
-  if( std::strcmp( name, "byte" ) == 0 ) { format = byte; return true; }
-  if( std::strcmp( name, "utf8" ) == 0 ) { format = utf8; return true; }
+  if( std::strcmp( name, "byte" ) == 0 ) { utf8 = false; return true; }
+  if( std::strcmp( name, "utf8" ) == 0 ) { utf8 = true; return true; }
   return false;
   }
