@@ -1,6 +1,6 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
-    Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
+    2012, 2013 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,9 +19,11 @@
 #include <algorithm>
 #include <cstdio>
 #include <vector>
+#include <stdint.h>
 
 #include "common.h"
 #include "rectangle.h"
+#include "segment.h"
 #include "ucs.h"
 #include "bitmap.h"
 #include "blob.h"
@@ -31,7 +33,7 @@
 
 Features::Features( const Blob & b_ )
   : b( b_ ), hbars_( -1 ), vbars_( -1 ),
-    hscan_valid( false ), vscan_valid( false ), lp( b, Profile::left ),
+    lp( b, Profile::left ),
     tp( b, Profile::top ), rp( b, Profile::right ), bp( b, Profile::bottom ),
     hp( b, Profile::height ), wp( b, Profile::width )
   {}
@@ -135,74 +137,79 @@ int Features::vbars() const		// FIXME small gaps not detected
   }
 
 
-// return the number of horizontal traces crossing every column
-//
-const std::vector< int > & Features::hscan() const
-  {
-  if( !hscan_valid )
-    {
-    int state = 0;
-    hscan_valid = true; hscan_.resize( b.width() );
-
-    for( int col = b.left(); col <= b.right(); ++col )
-      {
-      hscan_[col-b.left()] = 0;
-      for( int row = b.top(); row <= b.bottom(); ++row )
-        {
-        bool black = b.get_bit( row, col );
-        switch( state )
-          {
-          case 0: if( black ) state = 1; else break;
-          case 1: if( !black || row == b.bottom() )
-                    { state = 0; ++hscan_[col-b.left()]; }
-          }
-        }
-      }
-    }
-  return hscan_;
-  }
-
-
 // return the number of vertical traces crossing every row
 //
-const std::vector< int > & Features::vscan() const
+int Features::segments_in_row( const int row ) const
   {
-  if( !vscan_valid )
+  if( row_scan.size() == 0 )
     {
-    int state = 0;
-    vscan_valid = true; vscan_.resize( b.height() );
+    int l = -1;			// begin of segment. -1 means no segment
+    row_scan.resize( b.height() );
 
     for( int row = b.top(); row <= b.bottom(); ++row )
-      {
-      vscan_[row-b.top()] = 0;
       for( int col = b.left(); col <= b.right(); ++col )
         {
         bool black = b.get_bit( row, col );
-        switch( state )
-          {
-          case 0: if( black ) state = 1; else break;
-          case 1: if( !black || col == b.right() )
-                    { state = 0; ++vscan_[row-b.top()]; }
-          }
+        if( l < 0 && black ) l = col;			// begin of segment
+        if( l >= 0 && ( !black || col == b.right() ) )	// end of segment
+          { row_scan[row-b.top()].push_back( Csegment( l, col - !black ) );
+            l = -1; }
         }
-      }
     }
-  return vscan_;
+  return row_scan[row-b.top()].size();
+  }
+
+
+// return the number of horizontal traces crossing every column
+//
+int Features::segments_in_col( const int col ) const
+  {
+  if( col_scan.size() == 0 )
+    {
+    int t = -1;			// begin of segment. -1 means no segment
+    col_scan.resize( b.width() );
+
+    for( int col = b.left(); col <= b.right(); ++col )
+      for( int row = b.top(); row <= b.bottom(); ++row )
+        {
+        bool black = b.get_bit( row, col );
+        if( t < 0 && black ) t = row;			// begin of segment
+        if( t >= 0 && ( !black || row == b.bottom() ) )	// end of segment
+          { col_scan[col-b.left()].push_back( Csegment( t, row - !black ) );
+            t = -1; }
+        }
+    }
+  return col_scan[col-b.left()].size();
+  }
+
+
+// return the column segment containing the point (row,col) if any
+//
+Csegment Features::col_segment( const int row, const int col ) const
+  {
+  const int segments = segments_in_col( col );
+  for( int i = 0; i < segments; ++i )
+    if( col_scan[col-b.left()][i].includes( row ) )
+      return col_scan[col-b.left()][i];
+  return Csegment();
   }
 
 
 int Features::test_misc( const Rectangle & charbox ) const
   {
-  if( hbars() == 1 && hbar(0).top() <= b.top() + ( b.height() / 10 ) &&
-      4 * hbar(0).height() <= b.height() &&
-      5 * hbar(0).width() >= 4 * b.width() &&
-      rp[hbar(0).bottom()-b.top()+2] - rp[hbar(0).bottom()-b.top()] < b.width() / 4 &&
-      rp.increasing( hbar(0).vcenter() - b.top() + 1 ) )
-    return '7';
+  if( bp.minima() == 1 )
+    {
+    if( hbars() == 1 && hbar(0).top() <= b.top() + ( b.height() / 10 ) &&
+        4 * hbar(0).height() <= b.height() &&
+        5 * hbar(0).width() >= 4 * b.width() &&
+        rp[hbar(0).bottom()-b.top()+2] - rp[hbar(0).bottom()-b.top()] < b.width() / 4 &&
+        rp.increasing( hbar(0).vcenter() - b.top() + 1 ) )
+      return '7';
 
-  if( b.height() > b.width() && rp.increasing() && !tp.decreasing() &&
-      b.seek_left( b.vcenter(), b.hcenter() ) <= b.left() )
-    return '7';
+    if( b.height() > b.width() && rp.increasing() && !tp.decreasing() &&
+        b.seek_left( b.vcenter(), b.hcenter() ) <= b.left() )
+      return '7';
+    }
 
   if( tp.minima( b.height() / 4 ) == 1 && bp.minima( b.height() / 4 ) == 1 )
     {
