@@ -1,6 +1,6 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
-    Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
+    2012, 2013 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,50 +21,11 @@
 #include <vector>
 
 #include "rectangle.h"
+#include "segment.h"
 #include "mask.h"
 
 
-void Segment::add_point( const int col ) throw()
-  {
-  if( !valid() ) left = right = col;
-  else if( col < left ) left = col;
-  else if( col > right ) right = col;
-  }
-
-
-void Segment::add_segment( const Segment & seg ) throw()
-  {
-  if( seg.valid() )
-    {
-    if( !valid() ) *this = seg;
-    else
-      {
-      if( seg.left < left ) left = seg.left;
-      if( seg.right > right ) right = seg.right;
-      }
-    }
-  }
-
-
-int Segment::distance( const Segment & seg ) const throw()
-  {
-  if( !valid() || !seg.valid() ) return INT_MAX;
-  if( seg.right < left ) return left - seg.right;
-  if( seg.left > right ) return seg.left - right;
-  return 0;
-  }
-
-
-int Segment::distance( const int col ) const throw()
-  {
-  if( !valid() ) return INT_MAX;
-  if( col < left ) return left - col;
-  if( col > right ) return col - right;
-  return 0;
-  }
-
-
-int Mask::left( const int row ) const throw()
+int Mask::left( const int row ) const
   {
   if( top() <= row && row <= bottom() && data[row-top()].valid() )
     return data[row-top()].left;
@@ -72,7 +33,7 @@ int Mask::left( const int row ) const throw()
   }
 
 
-int Mask::right( const int row ) const throw()
+int Mask::right( const int row ) const
   {
   if( top() <= row && row <= bottom() && data[row-top()].valid() )
     return data[row-top()].right;
@@ -83,7 +44,7 @@ int Mask::right( const int row ) const throw()
 void Mask::top( const int t )
   {
   if( t == top() ) return;
-  if( t < top() ) data.insert( data.begin(), top() - t, Segment() );
+  if( t < top() ) data.insert( data.begin(), top() - t, Csegment() );
   else data.erase( data.begin(), data.begin() + ( t - top() ) );
   Rectangle::top( t );
   }
@@ -101,8 +62,8 @@ void Mask::add_mask( const Mask & m )
   if( m.bottom() > bottom() ) bottom( m.bottom() );
   for( int i = m.top(); i <= m.bottom(); ++i )
     {
-    Segment & seg = data[i-top()];
-    seg.add_segment( m.data[i-m.top()] );
+    Csegment & seg = data[i-top()];
+    seg.add_csegment( m.data[i-m.top()] );
     if( seg.left < left() ) left( seg.left );
     if( seg.right > right() ) right( seg.right );
     }
@@ -121,36 +82,36 @@ void Mask::add_rectangle( const Rectangle & re )
   {
   if( re.top() < top() ) top( re.top() );
   if( re.bottom() > bottom() ) bottom( re.bottom() );
-  const Segment rseg( re.left(), re.right() );
+  const Csegment rseg( re.left(), re.right() );
   for( int i = re.top(); i <= re.bottom(); ++i )
     {
-    Segment & seg = data[i-top()];
-    seg.add_segment( rseg );
+    Csegment & seg = data[i-top()];
+    seg.add_csegment( rseg );
     if( seg.left < left() ) left( seg.left );
     if( seg.right > right() ) right( seg.right );
     }
   }
 
 
-bool Mask::includes( const Rectangle & re ) const throw()
+bool Mask::includes( const Rectangle & re ) const
   {
   if( re.top() < top() || re.bottom() > bottom() ) return false;
-  const Segment seg( re.left(), re.right() );
+  const Csegment seg( re.left(), re.right() );
   for( int i = re.top(); i <= re.bottom(); ++i )
     if( !data[i-top()].includes( seg ) ) return false;
   return true;
   }
 
 
-bool Mask::includes( const int row, const int col ) const throw()
+bool Mask::includes( const int row, const int col ) const
   {
   return ( row >= top() && row <= bottom() && data[row-top()].includes( col ) );
   }
 
 
-int Mask::distance( const Rectangle & re ) const throw()
+int Mask::distance( const Rectangle & re ) const
   {
-  const Segment seg( re.left(), re.right() );
+  const Csegment seg( re.left(), re.right() );
   int mindist = INT_MAX;
   for( int i = bottom(); i >= top(); --i )
     {
@@ -165,7 +126,7 @@ int Mask::distance( const Rectangle & re ) const throw()
   }
 
 
-int Mask::distance( const int row, const int col ) const throw()
+int Mask::distance( const int row, const int col ) const
   {
   int mindist = INT_MAX;
   for( int i = bottom(); i >= top(); --i )
