@@ -1,5 +1,5 @@
 /*  Ocradlib - Optical Character Recognition library
-    Copyright (C) 2009, 2010 Antonio Diaz Diaz.
+    Copyright (C) 2009, 2010, 2011, 2012, 2013 Antonio Diaz Diaz.
 
     This library is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <cstring>
 #include <string>
 #include <vector>
+#include <stdint.h>
 
 #include "ocradlib.h"
 #include "common.h"
@@ -53,7 +54,7 @@ struct OCRAD_Descriptor
   Control control;
   std::string text;
 
-  OCRAD_Descriptor() throw()
+  OCRAD_Descriptor()
     :
     page_image( 0 ),
     textpage( 0 ),
@@ -77,7 +78,8 @@ const char * OCRAD_version() { return OCRAD_version_string; }
 
 OCRAD_Descriptor * OCRAD_open()
   {
-  OCRAD_Descriptor * ocrdes = new( std::nothrow ) OCRAD_Descriptor;
+  verbosity = -1;			// keep library silent
+  OCRAD_Descriptor * const ocrdes = new( std::nothrow ) OCRAD_Descriptor;
   if( !ocrdes ) return 0;
   return ocrdes;
   }
@@ -101,8 +103,7 @@ OCRAD_Errno OCRAD_get_errno( OCRAD_Descriptor * const ocrdes )
 
 
 int OCRAD_set_image( OCRAD_Descriptor * const ocrdes,
-                     const OCRAD_Pixmap * const image,
-                     const unsigned char invert )
+                     const OCRAD_Pixmap * const image, const bool invert )
   {
   if( !ocrdes ) return -1;
   if( !image || image->height < 3 || image->width < 3 ||
@@ -113,7 +114,7 @@ int OCRAD_set_image( OCRAD_Descriptor * const ocrdes,
 
   try
     {
-    Page_image * page_image = new Page_image( *image, invert );
+    Page_image * const page_image = new Page_image( *image, invert );
     if( ocrdes->textpage )
       { delete ocrdes->textpage; ocrdes->textpage = 0; }
     if( ocrdes->page_image ) delete ocrdes->page_image;
@@ -126,8 +127,7 @@ int OCRAD_set_image( OCRAD_Descriptor * const ocrdes,
 
 
 int OCRAD_set_image_from_file( OCRAD_Descriptor * const ocrdes,
-                               const char * const filename,
-                               const unsigned char invert )
+                               const char * const filename, const bool invert )
   {
   if( !ocrdes ) return -1;
   FILE * infile = 0;
@@ -140,7 +140,7 @@ int OCRAD_set_image_from_file( OCRAD_Descriptor * const ocrdes,
   int retval = 0;
   try
     {
-    Page_image * page_image = new Page_image( infile, invert );
+    Page_image * const page_image = new Page_image( infile, invert );
     if( ocrdes->textpage )
       { delete ocrdes->textpage; ocrdes->textpage = 0; }
     if( ocrdes->page_image ) delete ocrdes->page_image;
@@ -155,8 +155,15 @@ int OCRAD_set_image_from_file( OCRAD_Descriptor * const ocrdes,
   }
 
 
-int OCRAD_set_threshold( OCRAD_Descriptor * const ocrdes,
-                         const int threshold )
+int OCRAD_set_utf8_format( OCRAD_Descriptor * const ocrdes, const bool utf8 )
+  {
+  if( !verify_descriptor( ocrdes ) ) return -1;
+  ocrdes->control.utf8 = utf8;
+  return 0;
+  }
+
+
+int OCRAD_set_threshold( OCRAD_Descriptor * const ocrdes, const int threshold )
   {
   if( !verify_descriptor( ocrdes ) ) return -1;
   if( threshold < -1 || threshold > 255 )
@@ -177,12 +184,12 @@ int OCRAD_scale( OCRAD_Descriptor * const ocrdes, const int value )
   }
 
 
-int OCRAD_recognize( OCRAD_Descriptor * const ocrdes,
-                     const unsigned char layout )
+int OCRAD_recognize( OCRAD_Descriptor * const ocrdes, const bool layout )
   {
   if( !verify_descriptor( ocrdes ) ) return -1;
-  Textpage * textpage = new( std::nothrow ) Textpage( *ocrdes->page_image, "",
-                                                      ocrdes->control, layout );
+  Textpage * const textpage =
+    new( std::nothrow ) Textpage( *ocrdes->page_image, "",
+                                  ocrdes->control, layout );
   if( !textpage )
     { ocrdes->ocr_errno = OCRAD_mem_error; return -1; }
   if( ocrdes->textpage ) delete ocrdes->textpage;
@@ -245,8 +252,7 @@ int OCRAD_result_chars_line( OCRAD_Descriptor * const ocrdes,
 
 
 const char * OCRAD_result_line( OCRAD_Descriptor * const ocrdes,
-                                const int blocknum,
-                                const int linenum )
+                                const int blocknum, const int linenum )
   {
   if( !verify_descriptor( ocrdes, true ) ) return 0;
   if( blocknum < 0 || blocknum >= ocrdes->textpage->textblocks() ||
@@ -256,8 +262,12 @@ const char * OCRAD_result_line( OCRAD_Descriptor * const ocrdes,
   const Textline & textline =
     ocrdes->textpage->textblock( blocknum ).textline( linenum );
   ocrdes->text.clear();
-  for( int i = 0; i < textline.characters(); ++i )
-    ocrdes->text += textline.character( i ).byte_result();
+  if( !ocrdes->control.utf8 )
+    for( int i = 0; i < textline.characters(); ++i )
+      ocrdes->text += textline.character( i ).byte_result();
+  else
+    for( int i = 0; i < textline.characters(); ++i )
+      ocrdes->text += textline.character( i ).utf8_result();
   ocrdes->text += '\n';
   return ocrdes->text.c_str();
   }
@@ -273,7 +283,12 @@ int OCRAD_result_first_character( OCRAD_Descriptor * const ocrdes )
     const Character & character =
       ocrdes->textpage->textblock( 0 ).textline( 0 ).character( 0 );
     if( character.guesses() )
-      ch = UCS::map_to_byte( character.guess( 0 ).code );
+      {
+      if( !ocrdes->control.utf8 )
+        ch = UCS::map_to_byte( character.guess( 0 ).code );
+      else
+        ch = character.guess( 0 ).code;
+      }
     }
   return ch;
   }
