@@ -1,6 +1,6 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
-    Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
+    2012, 2013 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include <cstdio>
 #include <string>
 #include <vector>
+#include <stdint.h>
 
 #include "common.h"
 #include "rational.h"
@@ -31,20 +32,20 @@
 
 namespace {
 
-unsigned char pnm_getrawbyte( FILE * const f )
+uint8_t pnm_getrawbyte( FILE * const f )
   {
   int ch = std::fgetc( f );
 
   if( ch == EOF )
     throw Page_image::Error( "end-of-file reading pnm file." );
 
-  return static_cast< unsigned char >( ch );
+  return ch;
   }
 
 
-unsigned char pnm_getc( FILE * const f )
+uint8_t pnm_getc( FILE * const f )
   {
-  unsigned char ch;
+  uint8_t ch;
   bool comment = false;
 
   do {
@@ -59,7 +60,7 @@ unsigned char pnm_getc( FILE * const f )
 
 int pnm_getint( FILE * const f )
   {
-  unsigned char ch;
+  uint8_t ch;
   int i = 0;
 
   do ch = pnm_getc( f ); while( std::isspace( ch ) );
@@ -76,9 +77,9 @@ int pnm_getint( FILE * const f )
   }
 
 
-unsigned char pbm_getbit( FILE * const f )
+uint8_t pbm_getbit( FILE * const f )
   {
-  unsigned char ch;
+  uint8_t ch;
 
   do ch = pnm_getc( f ); while( std::isspace( ch ) );
 
@@ -113,16 +114,16 @@ void Page_image::read_p4( FILE * const f, const bool invert )
     for( int row = 0; row < rows; ++row )
       for( int col = 0; col < cols; )
         {
-        unsigned char byte = pnm_getrawbyte( f );
-        for( unsigned char mask = 0x80; mask > 0 && col < cols; mask >>= 1, ++col )
+        uint8_t byte = pnm_getrawbyte( f );
+        for( uint8_t mask = 0x80; mask > 0 && col < cols; mask >>= 1, ++col )
           data[row].push_back( ( byte & mask ) ? 0 : 1 );
         }
   else
     for( int row = 0; row < rows; ++row )
       for( int col = 0; col < cols; )
         {
-        unsigned char byte = pnm_getrawbyte( f );
-        for( unsigned char mask = 0x80; mask > 0 && col < cols; mask >>= 1, ++col )
+        uint8_t byte = pnm_getrawbyte( f );
+        for( uint8_t mask = 0x80; mask > 0 && col < cols; mask >>= 1, ++col )
           data[row].push_back( ( byte & mask ) ? 1 : 0 );
         }
   }
@@ -160,7 +161,7 @@ void Page_image::read_p5( FILE * const f, const bool invert )
   for( int row = 0; row < rows; ++row )
     for( int col = 0; col < cols; ++col )
       {
-      unsigned char val = pnm_getrawbyte( f );
+      uint8_t val = pnm_getrawbyte( f );
       if( val > maxval_ ) throw Page_image::Error( "value > maxval in pgm file." );
       if( invert ) val = maxval_ - val;
       data[row].push_back( val );
@@ -205,12 +206,12 @@ void Page_image::read_p6( FILE * const f, const bool invert )
   for( int row = 0; row < rows; ++row )
     for( int col = 0; col < cols; ++col )
       {
-      const unsigned char r = pnm_getrawbyte( f );	// Red value
-      const unsigned char g = pnm_getrawbyte( f );	// Green value
-      const unsigned char b = pnm_getrawbyte( f );	// Blue value
+      const uint8_t r = pnm_getrawbyte( f );	// Red value
+      const uint8_t g = pnm_getrawbyte( f );	// Green value
+      const uint8_t b = pnm_getrawbyte( f );	// Blue value
       if( r > maxval_ || g > maxval_ || b > maxval_ )
         throw Page_image::Error( "value > maxval in ppm file." );
-      unsigned char val;
+      uint8_t val;
       if( !invert ) val = std::min( r, std::min( g, b ) );
       else val = maxval_ - std::max( r, std::max( g, b ) );
       data[row].push_back( val );
@@ -245,11 +246,11 @@ Page_image::Page_image( FILE * const f, const bool invert )
   if( width() < 3 || height() < 3 )
     throw Error( "image too small. Minimum size is 3x3." );
   if( INT_MAX / width() < height() )
-    throw Error( "image too big. `int' will overflow." );
+    throw Error( "image too big. 'int' will overflow." );
   }
 
   data.resize( height() );
-  for( unsigned int row = 0; row < data.size(); ++row )
+  for( unsigned row = 0; row < data.size(); ++row )
     data[row].reserve( width() );
 
   switch( filetype )
@@ -270,7 +271,7 @@ Page_image::Page_image( FILE * const f, const bool invert )
   }
 
 
-bool Page_image::save( FILE * const f, const char filetype ) const throw()
+bool Page_image::save( FILE * const f, const char filetype ) const
   {
   if( filetype < '1' || filetype > '6' ) return false;
   std::fprintf( f, "P%c\n%d %d\n", filetype, width(), height() );
@@ -287,7 +288,7 @@ bool Page_image::save( FILE * const f, const char filetype ) const throw()
   else if( filetype == '4' )				// pbm RAWBITS
     for( int row = top(); row <= bottom(); ++row )
       {
-      unsigned char byte = 0, mask = 0x80;
+      uint8_t byte = 0, mask = 0x80;
       for( int col = left(); col <= right(); ++col )
         {
         if( get_bit( row, col ) ) byte |= mask;
@@ -312,17 +313,17 @@ bool Page_image::save( FILE * const f, const char filetype ) const throw()
       {
       for( int col = left(); col < right(); ++col )
         {
-        const unsigned char d = data[row][col];
+        const uint8_t d = data[row][col];
         std::fprintf( f, "%d %d %d ", d, d, d );
         }
-      const unsigned char d = data[row][right()];
+      const uint8_t d = data[row][right()];
       std::fprintf( f, "%d %d %d\n", d, d, d );
       }
   else if( filetype == '6' )				// ppm RAWBITS
     for( int row = top(); row <= bottom(); ++row )
       for( int col = left(); col <= right(); ++col )
         {
-        const unsigned char d = data[row][col];
+        const uint8_t d = data[row][col];
         std::fprintf( f, "%c %c %c ", d, d, d );
         }
   return true;
