@@ -1,6 +1,6 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009
-    Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
+    2012, 2013 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #include <algorithm>
 #include <cstdio>
 #include <vector>
+#include <stdint.h>
 
 #include "common.h"
 #include "rectangle.h"
@@ -27,74 +28,72 @@
 #include "profile.h"
 
 
-Profile::Profile( const Bitmap & b, Type t ) throw()
-  : bitmap_( &b ), type( t ),
+Profile::Profile( const Bitmap & bm_, const Type t )
+  : bm( bm_ ), type( t ),
     limit_( -1 ), max_( -1 ), min_( -1 ), mean_( -1 ),
     isconcave_( -1 ), isconvex_( -1 ), isflat_( -1 ), isflats_( -1 ),
     ispit_( -1 ), istpit_( -1 ), isupit_( -1 ), isvpit_( -1 ), istip_( -1 ) {}
 
 
-void Profile::initialize() throw()
+void Profile::initialize()
   {
-  const Bitmap & b = *bitmap_;
-
   switch( type )
     {
     case left :
-      data.resize( b.height() ); limit_ = b.width();
-      for( int row = b.top(); row <= b.bottom(); ++row )
+      data.resize( bm.height() ); limit_ = bm.width();
+      for( int row = bm.top(); row <= bm.bottom(); ++row )
         {
-        int j = b.left();
-        while( j <= b.right() && !b.get_bit( row, j ) ) ++j;
-        data[row-b.top()] = j - b.left();
+        int j = bm.left();
+        while( j <= bm.right() && !bm.get_bit( row, j ) ) ++j;
+        data[row-bm.top()] = j - bm.left();
         } break;
     case top :
-      data.resize( b.width() ); limit_ = b.height();
-      for( int col = b.left(); col <= b.right(); ++col )
+      data.resize( bm.width() ); limit_ = bm.height();
+      for( int col = bm.left(); col <= bm.right(); ++col )
         {
-        int j = b.top();
-        while( j <= b.bottom() && !b.get_bit( j, col ) ) ++j;
-        data[col-b.left()] = j - b.top();
+        int j = bm.top();
+        while( j <= bm.bottom() && !bm.get_bit( j, col ) ) ++j;
+        data[col-bm.left()] = j - bm.top();
         } break;
     case right :
-      data.resize( b.height() ); limit_ = b.width();
-      for( int row = b.top(); row <= b.bottom(); ++row )
+      data.resize( bm.height() ); limit_ = bm.width();
+      for( int row = bm.top(); row <= bm.bottom(); ++row )
         {
-        int j = b.right();
-        while( j >= b.left() && !b.get_bit( row, j ) ) --j;
-        data[row-b.top()] = b.right() - j;
+        int j = bm.right();
+        while( j >= bm.left() && !bm.get_bit( row, j ) ) --j;
+        data[row-bm.top()] = bm.right() - j;
         } break;
     case bottom :
-      data.resize( b.width() ); limit_ = b.height();
-      for( int col = b.left(); col <= b.right(); ++col )
+      data.resize( bm.width() ); limit_ = bm.height();
+      for( int col = bm.left(); col <= bm.right(); ++col )
         {
-        int j = b.bottom();
-        while( j >= b.top() && !b.get_bit( j, col ) ) --j;
-        data[col-b.left()] = b.bottom() - j;
+        int j = bm.bottom();
+        while( j >= bm.top() && !bm.get_bit( j, col ) ) --j;
+        data[col-bm.left()] = bm.bottom() - j;
         } break;
     case height :
-      data.resize( b.width() ); limit_ = b.height();
-      for( int col = b.left(); col <= b.right(); ++col )
+      data.resize( bm.width() ); limit_ = bm.height();
+      for( int col = bm.left(); col <= bm.right(); ++col )
         {
-        int u = b.top(), d = b.bottom();
-        while( u <= d && !b.get_bit( u, col ) ) ++u;
-        while( u <= d && !b.get_bit( d, col ) ) --d;
-        data[col-b.left()] = d - u + 1;
+        int u = bm.top(), d = bm.bottom();
+        while( u <= d && !bm.get_bit( u, col ) ) ++u;
+        while( u <= d && !bm.get_bit( d, col ) ) --d;
+        data[col-bm.left()] = d - u + 1;
         } break;
     case width :
-      data.resize( b.height() ); limit_ = b.width();
-      for( int row = b.top(); row <= b.bottom(); ++row )
+      data.resize( bm.height() ); limit_ = bm.width();
+      for( int row = bm.top(); row <= bm.bottom(); ++row )
         {
-        int l = b.left(), r = b.right();
-        while( l <= r && !b.get_bit( row, l ) ) ++l;
-        while( l <= r && !b.get_bit( row, r ) ) --r;
-        data[row-b.top()] = r - l + 1;
+        int l = bm.left(), r = bm.right();
+        while( l <= r && !bm.get_bit( row, l ) ) ++l;
+        while( l <= r && !bm.get_bit( row, r ) ) --r;
+        data[row-bm.top()] = r - l + 1;
         } break;
     }
   }
 
 
-int Profile::mean() throw()
+int Profile::mean()
   {
   if( mean_ < 0 )
     {
@@ -107,7 +106,7 @@ int Profile::mean() throw()
   }
 
 
-int Profile::max() throw()
+int Profile::max()
   {
   if( max_ < 0 )
     {
@@ -119,7 +118,7 @@ int Profile::max() throw()
   }
 
 
-int Profile::max( int l, int r ) throw()
+int Profile::max( const int l, int r )
   {
   if( limit_ < 0 ) initialize();
   if( r < 0 ) r = samples() - 1;
@@ -129,7 +128,7 @@ int Profile::max( int l, int r ) throw()
   }
 
 
-int Profile::min() throw()
+int Profile::min()
   {
   if( min_ < 0 )
     {
@@ -141,7 +140,7 @@ int Profile::min() throw()
   }
 
 
-int Profile::min( int l, int r ) throw()
+int Profile::min( const int l, int r )
   {
   if( limit_ < 0 ) initialize();
   if( r < 0 ) r = samples() - 1;
@@ -151,7 +150,7 @@ int Profile::min( int l, int r ) throw()
   }
 
 
-int Profile::operator[]( int i ) throw()
+int Profile::operator[]( int i )
   {
   if( limit_ < 0 ) initialize();
   if( i < 0 ) i = 0;
@@ -160,27 +159,27 @@ int Profile::operator[]( int i ) throw()
   }
 
 
-int Profile::area( int l, int r ) throw()
+int Profile::area( const int l, int r )
   {
   if( limit_ < 0 ) initialize();
   if( r < 0 ) r = samples() - 1;
-  int area = 0;
-  for( int i = l; i <= r; ++i ) area += data[i];
-  return area;
+  int a = 0;
+  for( int i = l; i <= r; ++i ) a += data[i];
+  return a;
   }
 
 
-bool Profile::increasing( int i ) throw()
+bool Profile::increasing( int i, const int min_delta )
   {
   if( limit_ < 0 ) initialize();
-  if( i < 0 || i > samples() - 2 || data[samples()-1] - data[i] < 2 )
+  if( i < 0 || i > samples() - 2 || data[samples()-1] - data[i] < min_delta )
     return false;
   while( ++i < samples() ) if( data[i] < data[i-1] ) return false;
   return true;
   }
 
 
-bool Profile::decreasing( int i ) throw()
+bool Profile::decreasing( int i )
   {
   if( limit_ < 0 ) initialize();
   const int noise = ( std::min( samples(), limit_ ) / 20 ) + 1;
@@ -192,7 +191,7 @@ bool Profile::decreasing( int i ) throw()
   }
 
 
-bool Profile::isconcave() throw()
+bool Profile::isconcave()
   {
   if( isconcave_ < 0 )
     {
@@ -219,7 +218,7 @@ bool Profile::isconcave() throw()
   }
 
 
-bool Profile::isconvex() throw()
+bool Profile::isconvex()
   {
   if( isconvex_ < 0 )
     {
@@ -268,12 +267,12 @@ bool Profile::isconvex() throw()
   }
 
 
-bool Profile::isflat() throw()
+bool Profile::isflat()
   {
   if( isflat_ < 0 )
     {
     isflat_ = false; if( limit_ < 0 ) initialize();
-    if( samples() < 15 ) return isflat_;
+    if( samples() < 10 ) return isflat_;
     int mn = data[samples()/2], mx = mn;
 
     for( int i = 1; i < samples() - 1; ++i )
@@ -284,12 +283,12 @@ bool Profile::isflat() throw()
   }
 
 
-bool Profile::isflats() throw()
+bool Profile::isflats()
   {
   if( isflats_ < 0 )
     {
     isflats_ = false; if( limit_ < 0 ) initialize();
-    if( samples() < 15 ) return isflats_;
+    if( samples() < 12 ) return isflats_;
     const int s1 = std::max( pos( 15 ), 3 );
     const int s2 = std::min( pos( 85 ), samples() - 4 );
     int mn = -1, mx = 0;
@@ -307,7 +306,7 @@ bool Profile::isflats() throw()
   }
 
 
-bool Profile::ispit() throw()
+bool Profile::ispit()
   {
   if( ispit_ < 0 )
     {
@@ -345,7 +344,7 @@ bool Profile::ispit() throw()
   }
 
 
-bool Profile::iscpit( const int cpos ) throw()
+bool Profile::iscpit( const int cpos )
   {
   if( limit_ < 0 ) initialize();
   if( samples() < 5 || cpos < 25 || cpos > 75 ) return false;
@@ -371,7 +370,7 @@ bool Profile::iscpit( const int cpos ) throw()
   }
 
 
-bool Profile::islpit() throw()
+bool Profile::islpit()
   {
   if( limit_ < 0 ) initialize();
   if( samples() < 5 ) return false;
@@ -391,7 +390,7 @@ bool Profile::islpit() throw()
   }
 
 
-bool Profile::istpit() throw()
+bool Profile::istpit()
   {
   if( istpit_ < 0 )
     {
@@ -409,7 +408,7 @@ bool Profile::istpit() throw()
   }
 
 
-bool Profile::isupit() throw()
+bool Profile::isupit()
   {
   if( isupit_ < 0 )
     {
@@ -446,7 +445,7 @@ bool Profile::isupit() throw()
   }
 
 
-bool Profile::isvpit() throw()
+bool Profile::isvpit()
   {
   if( isvpit_ < 0 )
     {
@@ -470,7 +469,7 @@ bool Profile::isvpit() throw()
   }
 
 
-bool Profile::istip() throw()
+bool Profile::istip()
   {
   if( istip_ < 0 )
     {
@@ -504,7 +503,7 @@ bool Profile::istip() throw()
   }
 
 
-bool Profile::isctip( const int cpos ) throw()
+bool Profile::isctip( const int cpos )
   {
   if( limit_ < 0 ) initialize();
   if( samples() < 5 || cpos < 25 || cpos > 75 ) return false;
@@ -540,7 +539,7 @@ bool Profile::isctip( const int cpos ) throw()
   }
 
 
-int Profile::imaximum() throw()
+int Profile::imaximum()
   {
   if( limit_ < 0 ) initialize();
   const int margin = ( samples() / 30 ) + 1;
@@ -556,7 +555,7 @@ int Profile::imaximum() throw()
   }
 
 
-int Profile::iminimum( int m, int th ) throw()
+int Profile::iminimum( const int m, int th )
   {
   if( limit_ < 0 ) initialize();
   const int margin = ( samples() / 30 ) + 1;
@@ -582,7 +581,7 @@ int Profile::iminimum( int m, int th ) throw()
   }
 
 
-int Profile::minima( int th ) throw()
+int Profile::minima( int th )
   {
   if( limit_ < 0 ) initialize();
   if( !samples() ) return 0;
@@ -603,7 +602,7 @@ int Profile::minima( int th ) throw()
   }
 
 
-bool Profile::straight( int * dy_ ) throw()
+bool Profile::straight( int * const dyp )
   {
   if( limit_ < 0 ) initialize();
   if( samples() < 5 ) return false;
@@ -621,6 +620,6 @@ bool Profile::straight( int * dy_ ) throw()
     if( d >= dmax && ( ( dx * data[i] ) < y || ( i >= xl && i <= xr ) ) )
       if( d > dmax || ( d == dmax && --faults < 0 ) ) return false;
     }
-  if( dy_ ) *dy_ = dy;
+  if( dyp ) *dyp = dy;
   return true;
   }
