@@ -1,6 +1,6 @@
 #! /bin/sh
 # check script for GNU Ocrad - Optical Character Recognition program
-# Copyright (C) 2009, 2010, 2011 Antonio Diaz Diaz.
+# Copyright (C) 2009, 2010, 2011, 2012, 2013 Antonio Diaz Diaz.
 #
 # This script is free software: you have unlimited permission
 # to copy, distribute and modify it.
@@ -20,21 +20,40 @@ fi
 
 if [ -d tmp ] ; then rm -rf tmp ; fi
 mkdir tmp
-printf "testing ocrad-%s..." "$2"
 cd "${objdir}"/tmp
 
-cat "${testdir}"/test.pbm > in || framework_failure
+in="${testdir}"/test.pbm
+txt="${testdir}"/test.txt
+utxt="${testdir}"/test_utf8.txt
 fail=0
 
-"${OCRAD}" -q in > out || fail=1
-cmp "${testdir}"/test.txt out || fail=1
+printf "testing ocrad-%s..." "$2"
+
+"${OCRAD}" -q -T-0.1 ${in} > /dev/null
+if [ $? != 1 ] ; then fail=1 ; printf - ; else printf . ; fi
+"${OCRAD}" -q -T 1.1 ${in} > /dev/null
+if [ $? != 1 ] ; then fail=1 ; printf - ; else printf . ; fi
+"${OCRAD}" -q -u -2,-1,1,1 ${in} > /dev/null
+if [ $? != 1 ] ; then fail=1 ; printf - ; else printf . ; fi
+"${OCRAD}" -q -u 1,1,1,1 ${in} > /dev/null
+if [ $? != 1 ] ; then fail=1 ; printf - ; else printf . ; fi
+
+"${OCRAD}" -q ${in} > out || fail=1
+cmp ${txt} out || fail=1
+printf .
+
+"${OCRAD}" -q -u 0,0,1,1 ${in} > out
+cmp ${txt} out || fail=1
+printf .
+
+"${OCRAD}" -q -u -1,-1,1,1 ${in} > out
+cmp ${txt} out || fail=1
 printf .
 
 test_chars()
 	{
 	for coord in ${coords} ; do
-		produced_chars="${produced_chars}`\"${OCRAD}\" -q -u${coord} in`" || fail=1
-		printf .
+		produced_chars="${produced_chars}`"${OCRAD}" -q -u${coord} ${in}`" || fail=1
 	done
 
 	if [ "${produced_chars}" != "${expected_chars}" ] ; then
@@ -43,6 +62,7 @@ test_chars()
 		echo "produced \"${produced_chars}\""
 		fail=1
 	fi
+	printf .
 	}
 
 coords=' 71,109,17,26  92,109,17,26 114,109,15,26 132,109,17,26
@@ -95,8 +115,11 @@ expected_chars="+*/#$&()?[\\]^{|}<>@~"
 produced_chars=
 test_chars
 
-"${OCRCHECK}" in > out || fail=1
-cmp "${testdir}"/test.txt out || fail=1
+"${OCRCHECK}" ${in} > out || fail=1
+cmp ${txt} out || fail=1
+printf .
+"${OCRCHECK}" ${in} --utf8 > out || fail=1
+cmp ${utxt} out || fail=1
 printf .
 
 echo
