@@ -1,6 +1,6 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
-    Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
+    2012, 2013 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,9 +17,11 @@
 */
 
 #include <algorithm>
+#include <climits>
 #include <cstdio>
 #include <string>
 #include <vector>
+#include <stdint.h>
 
 #include "common.h"
 #include "rational.h"
@@ -39,7 +41,7 @@ void insert_line( std::vector< Textline * > & textlinep_vector, int i )
   { textlinep_vector.insert( textlinep_vector.begin() + i, new Textline ); }
 
 
-void delete_line( std::vector< Textline * > & textlinep_vector, int i ) throw()
+void delete_line( std::vector< Textline * > & textlinep_vector, int i )
   {
   delete textlinep_vector[i];
   textlinep_vector.erase( textlinep_vector.begin() + i );
@@ -50,7 +52,7 @@ void delete_line( std::vector< Textline * > & textlinep_vector, int i ) throw()
 //
 void join_characters( std::vector< Textline * > & tlpv )
   {
-  for( unsigned int current_line = 0; current_line < tlpv.size(); ++current_line )
+  for( unsigned current_line = 0; current_line < tlpv.size(); ++current_line )
     {
     Textline & line = *tlpv[current_line];
     for( int i = 0 ; i < line.characters() - 1; )
@@ -95,7 +97,7 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
   std::vector< Blob * > pending_tall;
   std::vector< Blob * > pending_short;
 
-  for( unsigned int begin = 0, end = 0; end < blobp_vector.size(); begin = end )
+  for( unsigned begin = 0, end = 0; end < blobp_vector.size(); begin = end )
     {
     int botmax = blobp_vector[begin]->bottom();		// make cuts
     while( ++end < blobp_vector.size() )
@@ -105,27 +107,26 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
       }
 
     // Classify blobs by height.
-    unsigned int samples = 0;
+    unsigned samples = 0;
     std::vector< int > height_distrib;
-    for( unsigned int i = begin; i < end; ++i )
+    for( unsigned i = begin; i < end; ++i )
       {
-      unsigned int h = blobp_vector[i]->height();
-      unsigned int w = blobp_vector[i]->width();
-      if( h < 10 || w >= 3 * h ) continue;
+      if( blobp_vector[i]->is_abnormal() ) continue;
+      unsigned h = blobp_vector[i]->height();
       if( h >= height_distrib.size() ) height_distrib.resize( h + 1 );
       ++height_distrib[h]; ++samples;
       }
-    if( !height_distrib.size() )
-      for( unsigned int i = begin; i < end; ++i )
+    if( !height_distrib.size() )		// all blobs are abnormal
+      for( unsigned i = begin; i < end; ++i )
         {
-        unsigned int h = blobp_vector[i]->height();
+        unsigned h = blobp_vector[i]->height();
         if( h >= height_distrib.size() ) height_distrib.resize( h + 1 );
         ++height_distrib[h]; ++samples;
         }
 
     int mean_height = 0;
     int valid_samples = 0;
-    for( unsigned int i = 0, count = 0; i < height_distrib.size(); ++i )
+    for( unsigned i = 0, count = 0; i < height_distrib.size(); ++i )
       {
       int a = height_distrib[i];
       if( 10 * ( count + a ) >= samples && 10 * count < 9 * samples )
@@ -134,11 +135,14 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
       }
     if( valid_samples ) mean_height /= valid_samples;
 
-    for( unsigned int i = begin; i < end; ++i )
+    for( unsigned i = begin; i < end; ++i )
       {
       Blob * const p = blobp_vector[i];
-      if( p->height() >= 2 * mean_height ) pending_tall.push_back( p );
-      else if( 2 * p->height() <= mean_height || p->height() <= 5 )
+      const bool a = p->is_abnormal();
+      if( p->height() >= 2 * mean_height ||
+          ( a && p->height() > mean_height ) ) pending_tall.push_back( p );
+      else if( 2 * p->height() <= mean_height || p->height() <= 5 ||
+               ( a && p->height() < mean_height ) )
         pending_short.push_back( p );
       else pending.push_back( p );
       }
@@ -146,7 +150,7 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
 
   if( !pending.size() )
     {
-    for( unsigned int i = 0; i < blobp_vector.size(); ++i )
+    for( unsigned i = 0; i < blobp_vector.size(); ++i )
       delete blobp_vector[i];
     blobp_vector.clear();
     return;
@@ -158,7 +162,7 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
   tlpv.push_back( new Textline );
   int current_line = min_line = textlines() - 1;
   tlpv[current_line]->shift_characterp( new Character( pending[0] ) );
-  for( unsigned int i = 1; i < pending.size(); ++i )
+  for( unsigned i = 1; i < pending.size(); ++i )
     {
     Blob & b = *pending[i];
     current_line = std::max( min_line, current_line - 2 );
@@ -201,7 +205,7 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
   // Insert tall blobs.
   // Seek up, then seek down, needed for slanted or curved lines.
   current_line = 0;
-  for( unsigned int i = 0; i < pending_tall.size(); ++i )
+  for( unsigned i = 0; i < pending_tall.size(); ++i )
     {
     Blob & b = *pending_tall[i];
     while( current_line > 0 &&
@@ -229,7 +233,7 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
   // Insert short blobs.
   // Seek up, then seek down, needed for slanted or curved lines.
   current_line = 0;
-  for( unsigned int i = 0; i < pending_short.size(); ++i )
+  for( unsigned i = 0; i < pending_short.size(); ++i )
     {
     Blob & b = *pending_short[i];
     while( current_line > 0 &&
@@ -349,7 +353,7 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
   }
 
 
-Textblock::~Textblock() throw()
+Textblock::~Textblock()
   {
   for( int i = textlines() - 1; i >= 0; --i ) delete tlpv[i];
   }
@@ -410,7 +414,7 @@ void Textblock::recognize( const Charset & charset, const Filter & filter )
   }
 
 
-const Textline & Textblock::textline( const int i ) const throw()
+const Textline & Textblock::textline( const int i ) const
   {
   if( i < 0 || i >= textlines() )
     Ocrad::internal_error( "line, index out of bounds" );
@@ -418,7 +422,7 @@ const Textline & Textblock::textline( const int i ) const throw()
   }
 
 
-int Textblock::characters() const throw()
+int Textblock::characters() const
   {
   int total = 0;
   for( int i = 0; i < textlines(); ++i )
@@ -427,7 +431,7 @@ int Textblock::characters() const throw()
   }
 
 
-void Textblock::print( const Control & control ) const throw()
+void Textblock::print( const Control & control ) const
   {
   for( int i = 0; i < textlines(); ++i )
     tlpv[i]->print( control );
@@ -435,8 +439,7 @@ void Textblock::print( const Control & control ) const throw()
   }
 
 
-void Textblock::dprint( const Control & control, bool graph, bool recursive )
-								const throw()
+void Textblock::dprint( const Control & control, bool graph, bool recursive ) const
   {
   std::fprintf( control.outfile, "%d lines\n\n", textlines() );
 
@@ -450,7 +453,7 @@ void Textblock::dprint( const Control & control, bool graph, bool recursive )
   }
 
 
-void Textblock::xprint( const Control & control ) const throw()
+void Textblock::xprint( const Control & control ) const
   {
   std::fprintf( control.exportfile, "lines %d\n", textlines() );
 
@@ -463,13 +466,13 @@ void Textblock::xprint( const Control & control ) const throw()
   }
 
 
-void Textblock::cmark( Page_image & page_image ) const throw()
+void Textblock::cmark( Page_image & page_image ) const
   {
   for( int i = 0; i < textlines(); ++i ) tlpv[i]->cmark( page_image );
   }
 
 
-void Textblock::lmark( Page_image & page_image ) const throw()
+void Textblock::lmark( Page_image & page_image ) const
   {
   for( int i = 0; i < textlines(); ++i ) page_image.draw_track( *tlpv[i] );
   }
