@@ -1,6 +1,6 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
-    Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
+    2012, 2013 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,12 +27,12 @@
 
 namespace {
 
-void error( const char * s ) throw()
-  { Ocrad::internal_error( s ); }
+void error( const char * const msg )
+  { Ocrad::internal_error( msg ); }
 
 
 int good_reference( const Rectangle & r1, const Rectangle & r2, int & val,
-                    int mean_height, int mean_width ) throw()
+                    const int mean_height, const int mean_width )
   {
   if( 4 * r1.height() >= 3 * mean_height &&
       4 * r2.height() >= 3 * mean_height &&
@@ -56,7 +56,7 @@ int good_reference( const Rectangle & r1, const Rectangle & r2, int & val,
 
 
 int set_l( const std::vector< Rectangle > & rectangle_vector,
-           int mean_height, int mean_width ) throw()
+           const int mean_height, const int mean_width )
   {
   const int rectangles = rectangle_vector.size();
   const int imax = rectangles / 4;
@@ -73,7 +73,7 @@ int set_l( const std::vector< Rectangle > & rectangle_vector,
 
 
 int set_r( const std::vector< Rectangle > & rectangle_vector,
-           int mean_height, int mean_width ) throw()
+           const int mean_height, const int mean_width )
   {
   const int rectangles = rectangle_vector.size();
   const int imin = rectangles - 1 - ( rectangles / 4 );
@@ -89,7 +89,7 @@ int set_r( const std::vector< Rectangle > & rectangle_vector,
   }
 
 
-Vrhomboid set_partial_track( const std::vector< Rectangle > & rectangle_vector ) throw()
+Vrhomboid set_partial_track( const std::vector< Rectangle > & rectangle_vector )
   {
   const int rectangles = rectangle_vector.size();
   int mean_vcenter = 0, mean_height = 0, mean_width = 0;
@@ -136,7 +136,7 @@ Vrhomboid set_partial_track( const std::vector< Rectangle > & rectangle_vector )
 
 
 Vrhomboid::Vrhomboid( const int l, const int lc, const int r, const int rc,
-                      const int h ) throw()
+                      const int h )
   {
   if( r < l || h <= 0 )
     {
@@ -149,28 +149,28 @@ Vrhomboid::Vrhomboid( const int l, const int lc, const int r, const int rc,
   }
 
 
-void Vrhomboid::left( const int l ) throw()
+void Vrhomboid::left( const int l )
   {
   if( l > right_ ) error( "left, bad parameter resizing a Vrhomboid" );
   left_ = l;
   }
 
 
-void Vrhomboid::right( const int r ) throw()
+void Vrhomboid::right( const int r )
   {
   if( r < left_ ) error( "right, bad parameter resizing a Vrhomboid" );
   right_ = r;
   }
 
 
-void Vrhomboid::height( const int h ) throw()
+void Vrhomboid::height( const int h )
   {
   if( h <= 0 ) error( "height, bad parameter resizing a Vrhomboid" );
   height_ = h;
   }
 
 
-void Vrhomboid::extend_left( const int l ) throw()
+void Vrhomboid::extend_left( const int l )
   {
   if( l > right_ )
     error( "extend_left, bad parameter resizing a Vrhomboid" );
@@ -178,7 +178,7 @@ void Vrhomboid::extend_left( const int l ) throw()
   }
 
 
-void Vrhomboid::extend_right( const int r ) throw()
+void Vrhomboid::extend_right( const int r )
   {
   if( r < left_ )
     error( "extend_right, bad parameter resizing a Vrhomboid" );
@@ -186,7 +186,7 @@ void Vrhomboid::extend_right( const int r ) throw()
   }
 
 
-int Vrhomboid::vcenter( const int col ) const throw()
+int Vrhomboid::vcenter( const int col ) const
   {
   const int dx = right_ - left_, dy = rvcenter_ - lvcenter_;
   int vc = lvcenter_;
@@ -195,7 +195,7 @@ int Vrhomboid::vcenter( const int col ) const throw()
   }
 
 
-bool Vrhomboid::includes( const Rectangle & r ) const throw()
+bool Vrhomboid::includes( const Rectangle & r ) const
   {
   if( r.left() < left_ || r.right() > right_ ) return false;
   const int tl = top( r.left() ), bl = bottom( r.left() );
@@ -205,7 +205,7 @@ bool Vrhomboid::includes( const Rectangle & r ) const throw()
   }
 
 
-bool Vrhomboid::includes( const int row, const int col ) const throw()
+bool Vrhomboid::includes( const int row, const int col ) const
   {
   if( col < left_ || col > right_ ) return false;
   const int t = top( col ), b = bottom( col );
@@ -215,7 +215,7 @@ bool Vrhomboid::includes( const int row, const int col ) const throw()
 
 // rectangle_vector must be ordered by increasing hcenter().
 //
-void Track::set_track( const std::vector< Rectangle > & rectangle_vector ) throw()
+void Track::set_track( const std::vector< Rectangle > & rectangle_vector )
   {
   if( data.size() ) data.clear();
   if( !rectangle_vector.size() ) return;
@@ -225,7 +225,7 @@ void Track::set_track( const std::vector< Rectangle > & rectangle_vector ) throw
 
   {
   int s1 = rectangle_vector[0].width(), s2 = 0;
-  for( unsigned int i = 1; i < rectangle_vector.size(); ++i )
+  for( unsigned i = 1; i < rectangle_vector.size(); ++i )
     {
     s1 += rectangle_vector[i].width();
     s2 += ( rectangle_vector[i].left() - rectangle_vector[i-1].right() );
@@ -233,7 +233,7 @@ void Track::set_track( const std::vector< Rectangle > & rectangle_vector ) throw
   max_gap = ( 5 * std::max( s1, s2 ) ) / rectangle_vector.size();
   }
 
-  for( unsigned int i = 0; i < rectangle_vector.size(); ++i )
+  for( unsigned i = 0; i < rectangle_vector.size(); ++i )
     {
     const Rectangle & r1 = rectangle_vector[i];
     tmp.push_back( r1 );
@@ -247,7 +247,7 @@ void Track::set_track( const std::vector< Rectangle > & rectangle_vector ) throw
       { last = false; data.push_back( set_partial_track( tmp ) ); tmp.clear(); }
     }
 
-  for( unsigned int i = 0; i + 1 < data.size(); ++i )
+  for( unsigned i = 0; i + 1 < data.size(); ++i )
     {
     const Vrhomboid & v1 = data[i];
     const Vrhomboid & v2 = data[i+1];
@@ -261,9 +261,9 @@ void Track::set_track( const std::vector< Rectangle > & rectangle_vector ) throw
   }
 
 
-int Track::bottom( const int col ) const throw()
+int Track::bottom( const int col ) const
   {
-  for( unsigned int i = 0; i < data.size(); ++i )
+  for( unsigned i = 0; i < data.size(); ++i )
     {
     const Vrhomboid & vr = data[i];
     if( col <= vr.right() || i >= data.size() - 1 ) return vr.bottom( col );
@@ -272,9 +272,9 @@ int Track::bottom( const int col ) const throw()
   }
 
 
-int Track::top( const int col ) const throw()
+int Track::top( const int col ) const
   {
-  for( unsigned int i = 0; i < data.size(); ++i )
+  for( unsigned i = 0; i < data.size(); ++i )
     {
     const Vrhomboid & vr = data[i];
     if( col <= vr.right() || i >= data.size() - 1 ) return vr.top( col );
@@ -283,9 +283,9 @@ int Track::top( const int col ) const throw()
   }
 
 
-int Track::vcenter( const int col ) const throw()
+int Track::vcenter( const int col ) const
   {
-  for( unsigned int i = 0; i < data.size(); ++i )
+  for( unsigned i = 0; i < data.size(); ++i )
     {
     const Vrhomboid & vr = data[i];
     if( col <= vr.right() || i >= data.size() - 1 ) return vr.vcenter( col );
@@ -294,9 +294,9 @@ int Track::vcenter( const int col ) const throw()
   }
 
 
-bool Track::includes( const Rectangle & r ) const throw()
+bool Track::includes( const Rectangle & r ) const
   {
-  for( unsigned int i = 0; i < data.size(); ++i )
+  for( unsigned i = 0; i < data.size(); ++i )
     if( data[i].includes( r ) ) return true;
   if( !data.size() ) return false;
   if( r.right() > data.back().right() )
@@ -315,9 +315,9 @@ bool Track::includes( const Rectangle & r ) const throw()
   }
 
 
-bool Track::includes( const int row, const int col ) const throw()
+bool Track::includes( const int row, const int col ) const
   {
-  for( unsigned int i = 0; i < data.size(); ++i )
+  for( unsigned i = 0; i < data.size(); ++i )
     if( data[i].includes( row, col ) ) return true;
   if( !data.size() ) return false;
   if( col > data.back().right() )
