@@ -1,6 +1,6 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009
-    Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
+    2012, 2013 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -103,22 +103,23 @@ enum { IEXCLAM = 0x00A1,	// inverted exclamation mark
        EURO    = 0x20AC 	// symbole euro
        };
 
-int base_letter( const int code ) throw();
-int compose( const int letter, const int accent ) throw();
-bool isalnum( const int code ) throw();
-bool isalpha( const int code ) throw();
-bool isdigit( const int code ) throw();
-bool islower( const int code ) throw();
-bool islower_ambiguous( const int code ) throw();
-bool islower_small( const int code ) throw();
-bool islower_small_ambiguous( const int code ) throw();
-bool isspace( const int code ) throw();
-bool isupper( const int code ) throw();
-bool isvowel( int code ) throw();
-unsigned char map_to_byte( const int code ) throw();
-const char * ucs_to_utf8( const int code ) throw();
-int to_nearest_digit( const int code ) throw();
-int to_nearest_letter( const int code ) throw();
-int toupper( const int code ) throw();
+int base_letter( const int code );
+int compose( const int letter, const int accent );
+bool isalnum( const int code );
+bool isalpha( const int code );
+bool isdigit( const int code );
+bool ishigh( const int code );			// high chars like "A1bp|"
+bool islower( const int code );
+bool islower_ambiguous( const int code );
+bool islower_small( const int code );
+bool islower_small_ambiguous( const int code );
+bool isspace( const int code );
+bool isupper( const int code );
+bool isvowel( int code );
+unsigned char map_to_byte( const int code );
+const char * ucs_to_utf8( const int code );
+int to_nearest_digit( const int code );
+int to_nearest_letter( const int code );
+int toupper( const int code );
 
 } // end namespace UCS
